class FieldsController < ApplicationController
  before_action :set_field, only: %i[ show edit update destroy reserve ]

  # GET /fields or /fields.json
  def index
    @fields = Field.all
  end

  # GET /fields/1 or /fields/1.json
  def show
    @matches = ['HUN-TUR', 'HUN-KOS', "BL-KBL"]
    @availability = {}
    for hour in 8..22 do
      @availability[hour] = {}
      for day in Date.today.beginning_of_week..Date.today.end_of_week
        szam = rand(100)
        @availability[hour][day] = szam < 5 ? @matches[szam%3] : ""
      end
    end
    @field.availability = @availability
  end

  # GET /fields/new
  def new
    @field = Field.new
  end

  # GET /fields/1/edit
  def edit
  end

  # POST /fields or /fields.json
  def create
    @field = Field.new(field_params)

    respond_to do |format|
      if @field.save
        format.html { redirect_to field_url(@field), notice: "Field was successfully created." }
        format.json { render :show, status: :created, location: @field }
      else
        format.html { render :new, status: :unprocessable_entity }
        format.json { render json: @field.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /fields/1 or /fields/1.json
  def update
    respond_to do |format|
      if @field.update(field_params)
        format.html { redirect_to field_url(@field), notice: "Field was successfully updated." }
        format.json { render :show, status: :ok, location: @field }
      else
        format.html { render :edit, status: :unprocessable_entity }
        format.json { render json: @field.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /fields/1 or /fields/1.json
  def destroy
    @field.destroy!

    respond_to do |format|
      format.html { redirect_to fields_url, notice: "Field was successfully destroyed." }
      format.json { head :no_content }
    end
  end

  def reserve
    @reservation = Object.new
    @hour = 8
    @day = Date.today.day
    @matches = [['HUN-TUR', 1], ['HUN-KOS', 2],  ["BL-KBL", 3]]
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_field
      @field = Field.find(params[:id])
    end

    # Only allow a list of trusted parameters through.
    def field_params
      params.require(:field).permit(:name, :address)
    end
end
